### R code from vignette source 'RandomKNN_Demo.Rnw'

###################################################
### code chunk number 1: library
###################################################
require(rknn)
require(Biobase)
require(genefilter)
require(golubEsets)
require(chemometrics)



###################################################
### code chunk number 2: Golub_data
###################################################
data(Golub_Train)
data(Golub_Test)


###################################################
### code chunk number 3: Golub_data_preprocess
###################################################
mmfilt <- function(r=5, d=500, na.rm=TRUE) {
  function(x) {
    minval <-  min(x, na.rm=na.rm)
    maxval <-  max(x, na.rm=na.rm)
    (maxval/minval > r) && (maxval-minval > d)
  }
}
GolubTrans <-function(eSet) {
      X<- Biobase::exprs(eSet)
      X[X<100]<- 100
      X[X>16000]<- 16000

      return(X)
}

gTrn <- GolubTrans(Golub_Train)
gTest <- GolubTrans(Golub_Test)
mmfun <- mmfilt()
ffun <- filterfun(mmfun)
sub <- genefilter(gTrn, ffun )
#sum(sub) ## Should get 3051

golubTrain<- log10(gTrn[sub,])
golubTest<- log10(gTest[sub,])

golub.train.cl<- Golub_Train$ALL.AML
golub.test.cl<- Golub_Test$ALL.AML

golub.train<- t(scale(golubTrain));
golub.test<- t(scale(golubTest)); 


###################################################
### code chunk number 4: Golub_rknn
###################################################
golub.rnn<- rknn(data=golub.train, newdata=golub.test, y=golub.train.cl,
	 r=821, mtry=55, seed=20081029);

golub.rnn 
confusion(golub.test.cl, fitted(golub.rnn))



###################################################
### code chunk number 5: Multiplicity
###################################################
length(varNotUsed(golub.rnn));
golub.varUsed<- varUsed(golub.rnn);
summary(golub.varUsed);


###################################################
### code chunk number 6: Multiplicity_Histogram
###################################################
#flamehist(golub.varUsed, xlab="Multiplicity", main="")
hist(golub.varUsed, xlab="Multiplicity", main="")


###################################################
### code chunk number 7: Golub_support
###################################################
golub.support<- rknnSupport(golub.train, golub.train.cl, k=3)
golub.support
plot(golub.support, main="Support Criterion Plot")


###################################################
### code chunk number 8: Golub_beg
###################################################
set.seed(20081031)
golub.beg<- rknnBeg(golub.train, golub.train.cl);
plot(golub.beg)


###################################################
### code chunk number 9: Golub_bel
###################################################
better.set<- prebestset(golub.beg);
golub.bel<- rknnBel(golub.train[,better.set], golub.train.cl);
plot(golub.bel, ylim=c(0.88, 1))


###################################################
### code chunk number 10: four_genes
###################################################
best.set<- bestset(golub.bel);
cat(best.set, sep=", "); #remove[1] and quote, and comma.


###################################################
### code chunk number 11: test_golub_by_four_genes
###################################################
test.class<- knn(golub.train[, best.set], golub.test[, best.set], golub.train.cl, k=3)
#test.class;
confusion(golub.test.cl, test.class);


###################################################
### code chunk number 12: PAC
###################################################
data(PAC)
x<- scale(PAC$X);
PAC.beg<- rknnBeg(data=x, y=PAC$y, k=3, r=500, pk=0.8)
plot(PAC.beg)

knn.reg(x[,bestset(PAC.beg)],  y=PAC$y, k=3)



